==> codegen-0.48.0.tgz: package/lib/generators/react-admin/app/template/src/dev/ImageCardTemplate.tsx <==
import { Button, Card, CardActions, CardContent, CardMedia, Typography } from "@mui/material";
import { CreateButton, DeleteButton, EditButton, ExportButton, ShowButton } from "react-admin";
import { useState } from "react";
import amplicodeImage from "./media/amplicode.png";

export const ImageCardTemplate = () => {

  /*vtl
  #if (!$card.itemsVariableName)
  const [cardData, setCardData] = useState<${card.itemType}>();
  #set($dataVariable = "cardData")
  #else
  #set($dataVariable = $card.itemsVariableName)
  #end
  */
  /*vtl #if (false)*/ useState(); /*vtl #end */

  return (
    <Card sx={{ maxWidth: 450,  }} /*vtl #if ($card.outlined) variant="outlined" #end */>
      <CardMedia sx={{ height: '16rem' }} image={amplicodeImage} />
      <CardContent>
        {/*vtl #if($card.titleProperty) */}
        <Typography variant="h4" component="div">
          {/*vtl {$dataVariable?.${card.titleProperty.name}} */}
        </Typography>
        {/*vtl #end */}
        {/*vtl #if($card.subTitleProperty) */}
        <Typography sx={{ mb: 1.5 }} color="text.secondary">
          {/*vtl {$dataVariable?.${card.subTitleProperty.name}} */}
        </Typography>
        {/*vtl #end */}
        {/*vtl #foreach($property in $card.itemProperties) */}
        {/*vtl #if (!$property.asTitle && !$property.asSubTitle) */}
        <Typography mr={1} component="span">{/*vtl {$dataVariable?.${property.name}} */}</Typography>
        {/*vtl #end */}
        {/*vtl #end */}
      </CardContent>
      {/*vtl #if ($card.actions.size() > 0)*/}
      <CardActions>
        {/*vtl #foreach($action in $card.actions) */}
        {/*vtl #if($action.type == 'show') */}
        <ShowButton /*vtl label="$action.label"*/ /*vtl record={$dataVariable}*/ onClick={() => {alert('TODO: specify resource or implement custom show logic')}}/>
        {/*vtl #elseif ($action.type == 'edit') */}
        <EditButton /*vtl label="$action.label"*/ /*vtl record={$dataVariable}*/ onClick={() => {alert('TODO: specify resource or implement custom edit logic')}} />
        {/*vtl #elseif ($action.type == 'delete') */}
        <DeleteButton /*vtl label="$action.label"*/ /*vtl record={$dataVariable}*/ onClick={() => {alert('TODO: specify resource or implement custom delete logic')}} />
        {/*vtl #elseif ($action.type == 'custom') */}
        <Button onClick={() => {alert('TODO: implement custom action logic')}}>{/*vtl $action.label */}</Button>
        {/*vtl #end */}
        {/*vtl #end */}
      </CardActions>
      {/*vtl #end */}
    </Card>
  )
}

==> codegen-0.49.0.tgz: package/lib/generators/react-admin/app/template/src/dev/ImageCardTemplate.tsx <==
import { Box, Button, Card, CardActions, CardContent, CardMedia, Typography } from "@mui/material";
import { CreateButton, DeleteButton, EditButton, ExportButton, ShowButton } from "react-admin";
import { useState } from "react";
import ImageStub from "./media/ImageStub.png";

export const ImageCardTemplate = () => {

  /*vtl
  #if (!$card.itemsVariableName)
  const [cardData, setCardData] = useState<${card.itemType}>();
  #set($dataVariable = "cardData")
  #else
  #set($dataVariable = $card.itemsVariableName)
  #end
  */
  /*vtl #if (false)*/ useState(); /*vtl #end */

  return (
    <Card sx={{ maxWidth: 450, /*vtl #if ($card.solid) color: 'common.white', backgroundColor: 'primary.main' #end */ }} /*vtl #if ($card.outlined) variant="outlined" #end */>
      <CardMedia sx={{ height: '12rem' }} image={ImageStub} />
      <CardContent>
        {/*vtl #if($card.titleProperty) */}
        <Typography variant="h4" component="div">
          {/*vtl {$dataVariable?.${card.titleProperty.name}} */}
        </Typography>
        {/*vtl #end */}
        {/*vtl #if($card.subTitleProperty) */}
        <Typography sx={{ mb: 1.5 }} color="text.secondary">
          {/*vtl {$dataVariable?.${card.subTitleProperty.name}} */}
        </Typography>
        {/*vtl #end */}

        {/*vtl #foreach($property in $card.itemProperties) */}
          {/*vtl #if (!$property.asTitle && !$property.asSubTitle) */}
            {/*vtl #if ($card.labelPosition == 'hidden') */}
              <Typography mr={1} component="span">{/*vtl {$dataVariable?.${property.name}} */}</Typography>
            {/*vtl #elseif ($card.labelPosition == 'top') */}
              <Typography variant="caption">{/*vtl ${property.label} */}</Typography>
              <Typography mb={1} component="p">{/*vtl {$dataVariable?.${property.name}} */}</Typography>
            {/*vtl #elseif ($card.labelPosition == 'inline') */}
              <Typography component="p">
                {/*vtl ${property.label} */}: <Box component="span" sx={{fontWeight: "bold"}}>{/*vtl {$dataVariable?.${property.name}} */}</Box>
              </Typography>
            {/*vtl #end */}
          {/*vtl #end */}
        {/*vtl #end */}
      </CardContent>
      {/*vtl #if ($card.actions.size() > 0)*/}
      <CardActions>
        {/*vtl #foreach($action in $card.actions) */}
        {/*vtl #if($action.type == 'show') */}
        <ShowButton /*vtl label="$action.label"*/ /*vtl record={$dataVariable}*/ onClick={() => {alert('TODO: specify resource or implement custom show logic')}}/>
        {/*vtl #elseif ($action.type == 'edit') */}
        <EditButton /*vtl label="$action.label"*/ /*vtl record={$dataVariable}*/ onClick={() => {alert('TODO: specify resource or implement custom edit logic')}} />
        {/*vtl #elseif ($action.type == 'delete') */}
        <DeleteButton /*vtl label="$action.label"*/ /*vtl record={$dataVariable}*/ onClick={() => {alert('TODO: specify resource or implement custom delete logic')}} />
        {/*vtl #elseif ($action.type == 'custom') */}
        <Button onClick={() => {alert('TODO: implement custom action logic')}}>{/*vtl $action.label */}</Button>
        {/*vtl #end */}
        {/*vtl #end */}
      </CardActions>
      {/*vtl #end */}
    </Card>
  )
}
